@@ -1,14 +1,13 @@
 from .manager import main, run
 from .mock import context
-from .mock.plugin_manager import PluginView, caller_info
+from .mock.dm.jsonpath import jsonpath
 from .mock.handlers.handler_context import HandlerContext
-from .mock import plugin_manager
-from blinker import Signal
 import os
 from .event import CustomEventReceiver
 from .checker import event
 from .checker import encoder, decoder
 from .checker import on_request, on_response, on_request_upstream, on_response_upstream
+from .plugins import get_plugin_storage
 from lyrebird import application
 from lyrebird.log import get_logger
 
@@ -34,20 +33,6 @@ def emit(event, *args, **kwargs):
     context.application.socket_io.emit(event, *args, **kwargs)
 
 
-def get_plugin_storage():
-    """
-    Get plugins storage dir path
-
-    :return: ~/.lyrebird/plugins/<plugin_name>
-    """
-    info = caller_info(index=2)
-    storage_name = info.top_module_name
-    plugin_storage_dir = os.path.abspath(os.path.join(APPLICATION_CONF_DIR, 'plugins/%s' % storage_name))
-    if not os.path.exists(plugin_storage_dir):
-        os.makedirs(plugin_storage_dir)
-    return plugin_storage_dir
-
-
 def subscribe(channel, func, *args, **kwargs):
     """
     订阅信号
@@ -81,11 +66,6 @@ def add_background_task(name, func):
     application.server['task'].add_task(name, func)
 
 
-def get_plugin_conf():
-    info = caller_info(index=2)
-    plugin_name = info.top_module_name
-    return plugin_manager.get_conf(plugin_name)
-
 
 """
 获取 Event server state
