@@ -8,7 +8,7 @@ from ..version import VERSION
 from lyrebird.base_server import ThreadServer
 from lyrebird import application
 from lyrebird import log
-
+import traceback
 
 """
 Mock server
@@ -74,6 +74,11 @@ class LyrebirdMockServer(ThreadServer):
             """
             return redirect(url_for('ui.index')+f'?v={VERSION}')
 
+        @self.app.errorhandler(Exception)
+        def on_app_error(error):
+            _logger.error(f'[mocker server exception]: {error.__class__.__name__} {error}\n{traceback.format_exc()}')
+            return application.make_fail_response(f'{error.__class__.__name__} {error}\n{traceback.format_exc()}')
+
     def run(self):
         server_ip = application.config.get('ip')
         _logger.warning(f'Core start on http://{server_ip}:{self.port}')
