@@ -1,3 +1,3 @@
 from .plugin_loader import manifest, get_plugin_storage
 from .plugin_manager import PluginManager
-from .status_bar import ClickableStatusText, ImageMenuItem, TextMenuItem, LinkMenuItem
+from .status_bar import ClickableStatusText, ImageMenuItem, TextMenuItem, LinkMenuItem, Selector
