@@ -96,22 +96,98 @@ def download(link, input_path):
         for chunck in resp.iter_content():
             f.write(chunck)
 
-
 class CaseInsensitiveDict(dict):
+    '''
+    A dict data-structure that ignore key's case.
+    Any read or write related operations will igonre key's case.
 
-    def __init__(self, dict):
-        for k,v in dict.items():
+    Example: 
+    <key: 'abc'> & <key: 'ABC'> will be treated as the same key, only one exists in this dict.
+    '''
+    
+    def __init__(self, raw_dict):
+        self.__key_map = {}
+        for k, v in raw_dict.items():
             self.__setitem__(k, v)
 
+    def __get_real_key(self, key):
+        return self.__key_map.get(key.lower(), key)
+
+    def __set_real_key(self, real_key):
+        if real_key.lower() not in self.__key_map:
+            self.__key_map[real_key.lower()] = real_key
+
+    def __pop_real_key(self, key):
+        return self.__key_map.pop(key.lower())
+
+    def __del_real_key(self, key):
+        del self.__key_map[key.lower()]
+
+    def __clear_key_map(self):
+        self.__key_map.clear()
+
     def __setitem__(self, key, value):
-        super(CaseInsensitiveDict, self).__setitem__(key.lower(), value)
+        real_key = self.__get_real_key(key)
+        self.__set_real_key(real_key)
+        super(CaseInsensitiveDict, self).__setitem__(real_key, value)
 
     def __getitem__(self, key):
-        return super(CaseInsensitiveDict, self).__getitem__(key.lower())
-    
-    def get(self, key, default=None):
-        return super(CaseInsensitiveDict, self).get(key.lower(), default)
+        return super(CaseInsensitiveDict, self).__getitem__(self.__get_real_key(key))
 
+    def get(self, key, default=None):
+        return super(CaseInsensitiveDict, self).get(self.__get_real_key(key), default)
+
+    def __delitem__(self, key):
+        real_key = self.__pop_real_key(key)
+        return super(CaseInsensitiveDict, self).__delitem__(real_key)
+
+    def __contains__(self, key):
+        return key.lower() in self.__key_map
+
+    def pop(self, key):
+        real_key = self.__pop_real_key(key)
+        return super(CaseInsensitiveDict, self).pop(real_key)
+
+    def popitem(self):
+        item = super(CaseInsensitiveDict, self).popitem()
+        if item:
+            self.__del_real_key(item[0])
+        return item
+
+    def clear(self):
+        self.__clear_key_map()
+        return super(CaseInsensitiveDict, self).clear()
+
+    def update(self, __m=None, **kwargs) -> None:
+        if __m:
+            for k, v in __m.items():
+                self.__setitem__(k, v)
+        if kwargs:
+            for k, v in kwargs.items():
+                self.__setitem__(k, v)
+
+class HookedDict(dict):
+    '''
+    Hook build-in dict to protect CaseInsensitiveDict data type.
+    Only <headers> value is CaseInsensitiveDict at present.
+    '''
+    
+    def __init__(self, raw_dict):
+        for k, v in raw_dict.items():
+            if type(v) == dict:
+                if k.lower() == 'headers':
+                    v = CaseInsensitiveDict(v)
+                else:
+                    v = HookedDict(v)
+            self.__setitem__(k, v)
+
+    def __setitem__(self, __k, __v) -> None:
+        if type(__v) == dict:
+            if __k.lower() == 'headers':
+                __v = CaseInsensitiveDict(__v)
+            else:
+                __v = HookedDict(__v)
+        return super(HookedDict, self).__setitem__(__k, __v)
 
 class TargetMatch:
 
